==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonWalkingArrowRight.md <==
# PersonWalkingArrowRight


```text
fontawesome-6/Solid/PersonWalkingArrowRight
```

```text
include('fontawesome-6/Solid/PersonWalkingArrowRight')
```



| Illustration | PersonWalkingArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonWalkingArrowRight.png) | ![illustration for PersonWalkingArrowRight](../../fontawesome-6/Solid/PersonWalkingArrowRight.Local.png) |




## PersonWalkingArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingArrowRight
include('fontawesome-6/Solid/PersonWalkingArrowRight')

' renders the element
PersonWalkingArrowRight('PersonWalkingArrowRight', 'Person Walking Arrow Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingArrowRight
include('fontawesome-6/Solid/PersonWalkingArrowRight')

' renders the element
PersonWalkingArrowRight('PersonWalkingArrowRight', 'Person Walking Arrow Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/PersonWalkingArrowRight.md <==
# PersonWalkingArrowRight


```text
fontawesome-6/Solid/PersonWalkingArrowRight
```

```text
include('fontawesome-6/Solid/PersonWalkingArrowRight')
```



| Illustration | PersonWalkingArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonWalkingArrowRight.png) | ![illustration for PersonWalkingArrowRight](../../fontawesome-6/Solid/PersonWalkingArrowRight.Local.png) |




## PersonWalkingArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingArrowRight
include('fontawesome-6/Solid/PersonWalkingArrowRight')

' renders the element
PersonWalkingArrowRight('PersonWalkingArrowRight', 'Person Walking Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingArrowRight
include('fontawesome-6/Solid/PersonWalkingArrowRight')

' renders the element
PersonWalkingArrowRight('PersonWalkingArrowRight', 'Person Walking Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```
